@@ -91,12 +91,16 @@ class ViewMenu(Menu):
             MenuEntry('&Patches', main_window.workspace.show_patches_view),
             MenuEntry('&Types', main_window.workspace.show_types_view),
             MenuEntry('&Functions', main_window.workspace.show_functions_view),
+            MenuEntry('&Traces', main_window.workspace.show_traces_view),
+            MenuEntry('&Trace Map', main_window.workspace.show_trace_map_view),
             MenuSeparator(),
             MenuEntry('Symbolic &Execution', main_window.workspace.show_symexec_view),
             MenuEntry('S&ymbolic States', main_window.workspace.show_states_view),
             MenuEntry('&Interaction', main_window.workspace.show_interaction_view),
             MenuEntry('&Registers', main_window.workspace.show_registers_view),
             MenuEntry('&Stack', main_window.workspace.show_stack_view),
+            MenuEntry('&Breakpoints', main_window.workspace.show_breakpoints_view),
+            MenuEntry('&Call Explorer', main_window.workspace.show_call_explorer_view),
             MenuSeparator(),
             MenuEntry('&Console', main_window.workspace.show_console_view),
             MenuEntry('&Log', main_window.workspace.show_log_view),
