@@ -1,6 +1,6 @@
 from typing import Optional, Tuple, TYPE_CHECKING
-
 from PySide2.QtCore import Qt
+from enum import Enum
 
 if TYPE_CHECKING:
     from angrmanagement.ui.widgets.qblock import QBlock
@@ -8,6 +8,12 @@ if TYPE_CHECKING:
     from angrmanagement.ui.views import DisassemblyView
 
 
+class DisassemblyLevel(Enum):
+    MachineCode = 0
+    LifterIR = 1
+    AIL = 2
+
+
 class QDisassemblyBaseControl:
     """
     The base control class of QLinearViewer and QDisassemblyGraph. Implements or declares common shorthands and methods.
@@ -17,8 +23,8 @@ class QDisassemblyBaseControl:
         self.workspace = workspace
         self.disasm_view: 'DisassemblyView' = disasm_view
         self._base_cls = base_cls
-
         self._insaddr_to_block = { }
+        self._disassembly_level = disasm_view.disassembly_level
 
     @property
     def infodock(self):
@@ -56,6 +62,10 @@ class QDisassemblyBaseControl:
 
         return None
 
+    def set_disassembly_level(self, level:DisassemblyLevel):
+        self._disassembly_level = level
+        self.reload()
+
     #
     # Event handlers
     #
