@@ -128,7 +128,8 @@ class QDisassemblyGraph(QDisassemblyBaseControl, QZoomableDraggableGraphicsView)
             branchfunc = lambda n: None
         else:
             include_ir = self._disassembly_level is DisassemblyLevel.LifterIR
-            self.disasm = self.workspace.instance.project.analyses.Disassembly(function=self._function_graph.function, include_ir=include_ir)
+            self.disasm = self.workspace.instance.project.analyses.Disassembly(function=self._function_graph.function,
+                                                                               include_ir=include_ir)
             view = self.workspace.view_manager.first_view_in_category('console')
             if view is not None:
                 view.push_namespace({
